Learn R Programming

vivaldi (version 1.0.1)

position_allele_freq: position_allele_freq

Description

Reads in a dataframe that has been arranged (arrange_data) and filtered (filter_variants) and outputs plots

Usage

position_allele_freq(vardf, segment, nt)

Value

A plot showing the the frequencies of the major and minor allele at the given position across all samples

Arguments

vardf

A rearranged (arrange_data) and filtered (filtered_variants) vcf dataframe

segment

Name of segment (must be in quotes)

nt

Position on segment (must be in quotes)

Examples

Run this code
position_allele_freq(example_filtered_SNV_df,"H1N1_NP", "1247")

Run the code above in your browser using DataLab