powered by
Reads in a dataframe that has been arranged (arrange_data) and filtered (filter_variants) and outputs plots
position_allele_freq(vardf, segment, nt)
A plot showing the the frequencies of the major and minor allele at the given position across all samples
A rearranged (arrange_data) and filtered (filtered_variants) vcf dataframe
Name of segment (must be in quotes)
Position on segment (must be in quotes)
position_allele_freq(example_filtered_SNV_df,"H1N1_NP", "1247")
Run the code above in your browser using DataLab